import datetime
import pytz
from flask import Flask
from flask import request
from flask import redirect
from flask import render_template
from flask import send_from_directory
from flask import json

app = Flask(__name__, static_url_path='')

if __name__ == "__main__":
    app.run()

# Startseite
@app.route('/')
def view_index():
    return 'Warpzone API, see: https://gitlab.warpzone.ms/infrastruktur/warpapi/blob/master/README.md'

# Statische Dateien 
@app.route('/files/<path:path>')
def send_file(path):
    return send_from_directory('files', path)

# Statusanzeige auf der Webseite 
@app.route('/static')
def view_static():
    spaceopen = False
    now = datetime.datetime.now(pytz.timezone('Europe/Berlin'))
    dayofweek = now.strftime("%w") 
    # Hardcode Mittwoch Abend offen 
    if dayofweek == "3":
        if now.hour >= 18:
            spaceopen = True
    # Hardcode Samstag Abend offen 
    if dayofweek == "6":
        if now.hour >= 18:
            spaceopen = True
    return render_template('static.html', open = spaceopen)

# Statusanzeige auf der Webseite 
@app.route('/status')
def data_status():
    spaceopen = 0
    now = datetime.datetime.now(pytz.timezone('Europe/Berlin'))
    dayofweek = now.strftime("%w") 
    # Hardcode Mittwoch Abend offen 
    if dayofweek == "3":
        if now.hour >= 18:
            spaceopen = 1 
    # Hardcode Samstag Abend offen 
    if dayofweek == "6":
        if now.hour >= 18:
            spaceopen = 1 
    data = {
        "tuerOffen": spaceopen,
        "tempLoungece": 25,
        "tempWerkstatt": 25,
        "timestamp": 0,
        "age": 0
    }
    
    response = app.response_class(
        response=json.dumps(data),
        status=200,
        mimetype='application/json'
    )
    return response

# Endpunkt für Einbindung in cpu.ccc.de 
# Eigentlich die SpaceAPI, aber so können einfacher Abweichungen implementiert werden
@app.route('/cccapi')
def data_cccapi():
    return redirect('/spaceapi', code=302)

# Implementierung der SpaceAPI
@app.route('/spaceapi')
def data_spaceapi():
    spaceopen = False
    now = datetime.datetime.now(pytz.timezone('Europe/Berlin'))
    dayofweek = now.strftime("%w") 
    # Hardcode Mittwoch Abend offen 
    if dayofweek == "3":
        if now.hour >= 18:
            spaceopen = True 
    # Hardcode Samstag Abend offen 
    if dayofweek == "6":
        if now.hour >= 18:
            spaceopen = True 
    data = {
        "api": "0.13",
        "space": "warpzone ", 
        "logo": "https://api.warpzone.ms/files/warpzone_logo.png",
        "url": "https://www.warpzone.ms",
        "location": {
            "address": "warpzone e.V., Am Hawerkamp 31 Maus G, 48155 Münster, Germany",
            "lat": "51.943376",
            "lon": "7.638216",
        },
        "contact": {
            "phone": "+49 251 39500271",
            "twitter": "@warpzone_ms",
            "email": "office@warpzone.ms",
            "irc": "irc://irc.freenode.net/#warpzone",
            "ml": "warpzone@warpzone.ms",
        },
        "issue_report_channels": [ 
            "email" 
        ],
        "feeds": {
            "blog": { 
                "type": "application/rss+xml",
                "url": "https://www.warpzone.ms/feed/",
            },
            "calendar": {
                "type": "application/calendar",
                "url": "https://www.google.com/calendar/ical/hc82sdjshuf1ru9f9eqcfq9bvs%40group.calendar.google.com/public/basic.ics",
            },
        },
        "state": {
            "open": spaceopen,
            "icon": {
                "open": "https://api.warpzone.ms/files/warpzone_open.png",
                "closed": "https://api.warpzone.ms/files/warpzone_closed.png",
            },
        },
    }
    
    response = app.response_class(
        response=json.dumps(data),
        status=200,
        mimetype='application/json'
    )
    return response
